==> grai_source_bigquery-0.2.0a3-py3-none-any.whl: grai_source_bigquery/base.py <==
from typing import List, Optional, Union

from grai_client.endpoints.client import BaseClient
from grai_client.integrations.base import (
    GraiIntegrationImplementationV1,
    SeparateNodesAndEdgesMixin,
)
from grai_schemas.v1.source import SourceSpec

from grai_source_bigquery.adapters import adapt_to_client
from grai_source_bigquery.loader import BigqueryConnector, LoggingConnector


class BigQueryParams:
    namespace: Optional[str] = None
    project: Optional[str] = None
    dataset: Optional[Union[str, List[str]]] = None
    credentials: Optional[str] = None
    log_parsing: Optional[bool] = False
    log_parsing_window: Optional[int] = 7


class BigQueryIntegration(SeparateNodesAndEdgesMixin, GraiIntegrationImplementationV1):
    def __init__(
        self,
        client: Optional[BaseClient] = None,
        source_name: Optional[str] = None,
        source: Optional[SourceSpec] = None,
        namespace: Optional[str] = None,
        project: Optional[str] = None,
        dataset: Optional[Union[str, List[str]]] = None,
        credentials: Optional[str] = None,
        log_parsing: Optional[bool] = False,
        log_parsing_window: Optional[int] = 7,
    ):
        super().__init__(client, source_name, source)

        self.connector = (
            BigqueryConnector(
                project=project,
                namespace=namespace,
                dataset=dataset,
                credentials=credentials,
            )
            if not log_parsing
            else LoggingConnector(
                project=project,
                namespace=namespace,
                dataset=dataset,
                credentials=credentials,
                window=log_parsing_window,
            )
        )

    def nodes(self):
        with self.connector.connect() as conn:
            connector_nodes = conn.nodes()
            grai_nodes = adapt_to_client(connector_nodes, self.source, self.version)
        return grai_nodes

    def edges(self):
        with self.connector.connect() as conn:
            connector_edges = conn.edges()
            grai_edges = adapt_to_client(connector_edges, self.source, self.version)
        return grai_edges

==> grai_source_bigquery-0.2.3-py3-none-any.whl: grai_source_bigquery/base.py <==
from typing import List, Optional, Union, Tuple


from grai_schemas.integrations.base import GraiIntegrationImplementation
from grai_schemas.v1.source import SourceV1

from grai_source_bigquery.adapters import adapt_to_client
from grai_source_bigquery.loader import BigqueryConnector, LoggingConnector
from grai_schemas.base import Event, SourcedEdge, SourcedNode


class BigQueryIntegration(GraiIntegrationImplementation):
    def __init__(
        self,
        source: SourceV1,
        version: Optional[str] = None,
        namespace: Optional[str] = None,
        project: Optional[str] = None,
        dataset: Optional[Union[str, List[str]]] = None,
        credentials: Optional[str] = None,
        log_parsing: Optional[bool] = False,
        log_parsing_window: Optional[int] = 7,
    ):
        super().__init__(source, version)

        self.connector = (
            BigqueryConnector(
                project=project,
                namespace=namespace,
                dataset=dataset,
                credentials=credentials,
            )
            if not log_parsing
            else LoggingConnector(
                project=project,
                namespace=namespace,
                dataset=dataset,
                credentials=credentials,
                window=log_parsing_window,
            )
        )

    def nodes(self) -> List[SourcedNode]:
        with self.connector.connect() as conn:
            connector_nodes = conn.nodes()
            grai_nodes = adapt_to_client(connector_nodes, self.source, self.version)
        return grai_nodes

    def edges(self) -> List[SourcedEdge]:
        with self.connector.connect() as conn:
            connector_edges = conn.edges()
            grai_edges = adapt_to_client(connector_edges, self.source, self.version)
        return grai_edges

    def get_nodes_and_edges(self) -> Tuple[List[SourcedNode], List[SourcedEdge]]:
        return self.nodes(), self.edges()

    def ready(self) -> bool:
        with self.connector.connect() as _:
            pass
        return True
